module.exports = defineTest({
	description: 'handles default exporting global variables',
	options: { output: { name: 'bundle' } }
});
